---
keywords:
  - 엑심베이
  - 해외결제
  - 정기결제
  - 결제연동
  - 채널설정방법
  - 채널추가
title: 엑심베이 채널설정방법
category: 결제서비스 (채널설정 및 이용안내) > 채널설정 > 채널설정
seo:
  title: 엑심베이 채널설정방법
  description: >-
    엑심베이 결제 연동을 위한 채널 설정 방법을 안내드립니다. '테스트 연동, 실 연동' 순으로 이뤄지며, 일본 편의점 결제 테스트 방까지
    안내하고 있습니다. 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
tags:
  - 엑심베이
  - 결제
  - 채널설정방법
pgCompanies:
  - 엑심베이
searchTags:
  - 엑심베이테스트
  - 편의점결제
  - 해외결제
  - 엑심베이연동
  - 엑심베이설정
  - 엑심베이 설정방법
  - 엑심베이
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="결제 연동을 위한 채널 설정 방법을 안내해 드립니다.
결제 연동을 위해서 채널설정은 필수이며 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
또한 채널 설정 없이 결제 연동을 하실 경우 정상적인 호출이 불가하며, 오류가 발생됩니다." />

<Callout content="[연동방식]
- 결제창 : 결제대행사(PG사)의 결제창을 띄워서 그 안에서 결제수단 선택 후 결제하는 방식
- API : 직접 구현한 UI를 통해 결제 수단 정보를 입력받아 API를 통해 결제하는 방식

[모듈버전]
- V1 : 포트원 결제모듈 V1. 다양한 결제대행사와 수단을 지원
- V2 : 포트원 차세대 결제 모듈로 직관적인 인터페이스를 지원
- 신모듈 : 결제대행사의 최신 버전의 모듈
- 구모듈 : 결제대행사의 구 버전의 모듈

[결제방식]
- 일반결제 : 구매자의 결제정보를 저장하지 않는 일회성 결제 (단건결제)
- 정기결제 : 구매자의 결제정보를 저장해놓고 재결제하는 결제 (정기 / 비 정기결제)
" title="참고사항" icon="💡" />

## <Highlight text="결제창 일반결제" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 엑심베이
  - 결제모듈 :  결제창 일반결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) 클릭
  - 결제창 일반결제 1849705C64 선택
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **일본 편의점결제 테스트 방법**

##### 1. 편의점결제 동작 방식

- 한국의 가상계좌와 같이, 결제창 내에서는 등록을 한 다음에 고객에게 이메일 / 문자로 전달되는 화면을 편의점 카운터에서 지불하며 처리합니다.

<Indent level="1">

- 포트원 내부에서는 pay\_method : vbank 로 기록됨
- Econtext 등록이 완료되었다는 콜백함수 및 웹훅 전송
  (status : ready 상태 / vbank\_num 은 unknown 으로 고정)
- Econtext 로부터 입금확인이 되면 포트원에서 엑심베이로부터 응답을 받아 status : paid 로 변경 후 결제완료처리에 대한 웹훅 전송

</Indent>

##### 2. 편의점결제 테스트 진행 순서

- 가상계좌와 같이 실제 고객이 입금한 결과를 테스트해야 하므로 아래와 같이 입금완료됨을 임의적으로 통지 받아보실 수 있습니다.

<Indent level="1">

- 엑심베이 테스트모드 ON상태에서  결제창 호출 진행
- 콜백 응답 중 pg\_tid 값을 별도로 메모 (포트원관리자페이지상에서는 PG사승인번호 컬럼에서 확인 가능)
- [엑심베이 테스트 화면 ↗](https://form.int.econ.ne.jp/paynotice "테스트") 로 이동 후 계정 로그인 \
  (아이디 : ectest / 비번 : #Gwecn25 )

</Indent>

<Indent level="2">

- ShopID : 361301, orderID :  PG사승인번호 입력
- 하단에 있는  登録 버튼 클릭
- 다음 페이지에서 한 번 더  登録 클릭
- 10분 후 결제상태가 status : paid 로 바뀌는지 확인 ( 이 때 입금에 대한 웹훅 발송됨 )

</Indent>

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : 엑심베이
  - 결제모듈 : 결제창 일반결제

#### **설정방법**

- 채널 속성 : 결제
- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- PG상점아이디 (MID) : 엑심베이로부터 발급받은 상점아이디
- Secret Key : 엑심베이 계약 후 발급받는 Secret Key.

<Callout title="엑심베이 개발가이드 보러가기↗" />
